# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`yum`](#yum): Manage yum (client, server, and key management)
* [`yum::server`](#yumserver): Manage a yum repository service
* [`yum::updatesd`](#yumupdatesd): Manage yum-updatesd which is available on EL5, though not EL6
This is defaulted to being disabled.

**Defined types**

* [`yum::repo`](#yumrepo): Manage individual yum repo files in /etc/yum.repos.d This was used
* [`yum::rpm_gpg_key`](#yumrpm_gpg_key): Downloads a public gpg key for a yum repo and installs the key
Uses wget and rpimport commands

## Classes

### yum

Manage yum (client, server, and key management)

#### Examples

##### Declaring the class

```puppet
include ::yum
```

#### Parameters

The following parameters are available in the `yum` class.

##### `config_path`

Data type: `Stdlib::Absolutepath`

Set the path to the yum.conf file, representing a fully qualified name.

Default value: '/etc/yum.conf'

##### `config_owner`

Data type: `String`

Set owner access to the yum.conf file, representing a user.

Default value: 'root'

##### `config_group`

Data type: `String`

Set group access to the yum.conf file, representing a group.

Default value: 'root'

##### `config_mode`

Data type: `Stdlib::Filemode`

Set access permissions for the yum.conf file, in numeric notation.

Default value: '0644'

##### `manage_repos`

Data type: `Boolean`

Trigger if files in /etc/yum.repos.d should get managed by Puppet exclusivly.
If set to true, all unmanged files in /etc/yum.repos.d (and below) will get
removed.

Default value: `false`

##### `repos_d_owner`

Data type: `String`

Set owner access to the /etc/yum.repos.d directory, representing a user.

Default value: 'root'

##### `repos_d_group`

Data type: `String`

Set group access to the /etc/yum.repos.d directory, representing a group.

Default value: 'root'

##### `repos_d_mode`

Data type: `Stdlib::Filemode`

Set access permissions for the /etc/yum.repos.d directory, in numeric notation.

Default value: '0755'

##### `repos_hiera_merge`

Data type: `Boolean`

Trigger to merge all found instances of yum::repos in Hiera. This is useful
for specifying repositories at different levels of the hierarchy and having
them all included in the catalog.

Default value: `true`

##### `rpm_gpg_keys_hiera_merge`

Data type: `Boolean`

Trigger to merge all found instances of yum::rpm_gpg_keys in Hiera. This is useful
for specifying repositories at different levels of the hierarchy and having
them all included in the catalog.

Default value: `true`

##### `repos`

Data type: `Optional[Hash]`

Hash of repos to pass to yum::repo. See yum::repo for more details.

Default value: `undef`

##### `rpm_gpg_keys`

Data type: `Optional[Hash]`

Hash of repos to pass to yum::rpm_gpg_keys. See yum::rpm_gpg_key for more details.

Default value: `undef`

##### `exclude_hiera_merge`

Data type: `Boolean`

Trigger to merge all found instances of yum::exclude in Hiera. This is useful
for specifying repositories at different levels of the hierarchy and having
them all included in the catalog.

Default value: `false`

##### `color_list_available_downgrade`

Data type: `Array`

color_list_available_downgrade setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_list_available_install`

Data type: `Array`

color_list_available_install setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_list_available_reinstall`

Data type: `Array`

color_list_available_reinstall setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_list_available_upgrade`

Data type: `Array`

color_list_available_upgrade setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_list_installed_extra`

Data type: `Array`

color_list_installed_extra setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_list_installed_newer`

Data type: `Array`

color_list_installed_newer setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_list_installed_older`

Data type: `Array`

color_list_installed_older setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_list_installed_reinstall`

Data type: `Array`

color_list_installed_reinstall setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_search_match`

Data type: `Array`

color_search_match setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_update_installed`

Data type: `Array`

color_update_installed setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_update_local`

Data type: `Array`

color_update_local setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `color_update_remote`

Data type: `Array`

color_update_remote setting in the main section of yum.conf.
Valid values are: 'bg:black', 'bg:blue', 'bg:cyan', 'bg:green', 'bg:magenta', 'bg:red', 'bg:white',
  'bg:yellow', 'blink', 'bold', 'dim', 'fg:black', 'fg:blue', 'fg:cyan', 'fg:green', 'fg:magenta',
  'fg:red', 'fg:white', 'fg:yellow', 'reverse', 'underline',
When empty, it will not be present in yum.conf.

Default value: []

##### `commands`

Data type: `Array`

commands setting in the main section of yum.conf.
When empty, it will not be present in yum.conf.

Default value: []

##### `exclude`

Data type: `Array`

exclude setting in the main section of yum.conf.
When empty, it will not be present in yum.conf.

Default value: []

##### `group_package_types`

Data type: `Array`

group_package_types setting in the main section of yum.conf.
Valid values are: , 'default', 'mandatory', and 'optional'.
When empty, it will not be present in yum.conf.

Default value: []

##### `history_record_packages`

Data type: `Array`

history_record_packages setting in the main section of yum.conf.
When empty, it will not be present in yum.conf.

Default value: []

##### `installonlypkgs`

Data type: `Array`

installonlypkgs setting in the main section of yum.conf.
When empty, it will not be present in yum.conf.

Default value: []

##### `kernelpkgnames`

Data type: `Array`

kernelpkgnames setting in the main section of yum.conf.
When empty, it will not be present in yum.conf.

Default value: []

##### `protected_packages`

Data type: `Array`

protected_packages setting in the main section of yum.conf.
When empty, it will not be present in yum.conf.

Default value: []

##### `tsflags`

Data type: `Array`

tsflags setting in the main section of yum.conf.
Valid values are: , 'justdb', 'nocontexts', 'nodocs', 'noscripts', 'notriggers', 'repackage', and 'test'
When empty, it will not be present in yum.conf.

Default value: []

##### `reposdir`

Data type: `Array[Stdlib::Absolutepath]`

reposdir setting in the main section of yum.conf.
Takes a list of one or more absolute paths.
When empty, it will not be present in yum.conf.

Default value: []

##### `distroverpkg`

Data type: `Optional[Variant[Boolean,String]]`

distroverpkg setting in the main section of yum.conf.
Will use the format distroverpk=$::operatingsystem-release (downcase) if true.
Alternatively you can also specify a free string text instead.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `alwaysprompt`

Data type: `Optional[Boolean]`

alwaysprompt setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `assumeyes`

Data type: `Optional[Boolean]`

assumeyes setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `clean_requirements_on_remove`

Data type: `Optional[Boolean]`

clean_requirements_on_remove setting in the main section of yum.conf.
True enables, false disables this feature. When clean, it will not be present in yum.conf.

Default value: `undef`

##### `color`

Data type: `Optional[Boolean]`

color setting in the main section of yum.conf.
True enables, false disables this feature. When clean, it will not be present in yum.conf.

Default value: `undef`

##### `diskspacecheck`

Data type: `Optional[Boolean]`

diskspacecheck setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `enable_group_conditionals`

Data type: `Optional[Boolean]`

enable_group_conditionals setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `exactarch`

Data type: `Optional[Boolean]`

exactarch setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `true`

##### `gpgcheck`

Data type: `Optional[Boolean]`

gpgcheck setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `false`

##### `groupremove_leaf_only`

Data type: `Optional[Boolean]`

groupremove_leaf_only setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `history_record`

Data type: `Optional[Boolean]`

history_record setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `keepalive`

Data type: `Optional[Boolean]`

keepalive setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `keepcache`

Data type: `Optional[Boolean]`

keepcache setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `true`

##### `localpkg_gpgcheck`

Data type: `Optional[Boolean]`

localpkg_gpgcheck setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `obsoletes`

Data type: `Optional[Boolean]`

obsoletes setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `true`

##### `overwrite_groups`

Data type: `Optional[Boolean]`

overwrite_groups setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `plugins`

Data type: `Optional[Boolean]`

plugins setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `false`

##### `protected_multilib`

Data type: `Optional[Boolean]`

protected_multilib setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `repo_gpgcheck`

Data type: `Optional[Boolean]`

repo_gpgcheck setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `reset_nice`

Data type: `Optional[Boolean]`

reset_nice setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `showdupesfromrepos`

Data type: `Optional[Boolean]`

showdupesfromrepos setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `skip_broken`

Data type: `Optional[Boolean]`

skip_broken setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `ssl_check_cert_permissions`

Data type: `Optional[Boolean]`

ssl_check_cert_permissions setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `sslverify`

Data type: `Optional[Boolean]`

sslverify setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `tolerant`

Data type: `Optional[Boolean]`

tolerant setting in the main section of yum.conf.
True enables, false disables this feature. When undef, it will not be present in yum.conf.

Default value: `false`

##### `debuglevel`

Data type: `Optional[Integer[0, 10]]`

debuglevel setting in the main section of yum.conf.
Takes any integer between 0 and 10. When undef, it will not be present in yum.conf.

Default value: 2

##### `errorlevel`

Data type: `Optional[Integer[0, 10]]`

errorlevel setting in the main section of yum.conf.
Takes any integer between 0 and 10. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `bandwidth`

Data type: `Optional[Integer]`

bandwidth setting in the main section of yum.conf.
Takes any integer. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `installonly_limit`

Data type: `Optional[Integer]`

installonly_limit setting in the main section of yum.conf.
Takes any integer. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `mirrorlist_expire`

Data type: `Optional[Integer]`

mirrorlist_expire setting in the main section of yum.conf.
Takes any integer. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `recent`

Data type: `Optional[Integer]`

recent setting in the main section of yum.conf.
Takes any integer. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `retries`

Data type: `Optional[Integer]`

retries setting in the main section of yum.conf.
Takes any integer. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `timeout`

Data type: `Optional[Integer]`

timeout setting in the main section of yum.conf.
Takes any integer. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `cachedir`

Data type: `Optional[Stdlib::Absolutepath]`

cachedir setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: '/var/cache/yum/$basearch/$releasever'

##### `installroot`

Data type: `Optional[Stdlib::Absolutepath]`

installroot setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `logfile`

Data type: `Optional[Stdlib::Absolutepath]`

logfile setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: '/var/log/yum.log'

##### `persistdir`

Data type: `Optional[Stdlib::Absolutepath]`

persistdir setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `pluginconfpath`

Data type: `Optional[Stdlib::Absolutepath]`

pluginconfpath setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `pluginpath`

Data type: `Optional[Stdlib::Absolutepath]`

pluginpath setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `sslcacert`

Data type: `Optional[Stdlib::Absolutepath]`

sslcacert setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `sslclientcert`

Data type: `Optional[Stdlib::Absolutepath]`

sslclientcert setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `sslclientkey`

Data type: `Optional[Stdlib::Absolutepath]`

sslclientkey setting in the main section of yum.conf.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `bugtracker_url`

Data type: `Optional[Stdlib::Httpurl]`

bugtracker_url setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `proxy`

Data type: `Optional[Stdlib::Httpurl]`

proxy setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `password`

Data type: `Optional[String]`

password setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `proxy_password`

Data type: `Optional[String]`

proxy_password setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `proxy_username`

Data type: `Optional[String]`

proxy_username setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `syslog_device`

Data type: `Optional[String]`

syslog_device setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `syslog_facility`

Data type: `Optional[String]`

syslog_facility setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `syslog_ident`

Data type: `Optional[String]`

syslog_ident setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `username`

Data type: `Optional[String]`

username setting in the main section of yum.conf. When undef, it will not be present in yum.conf.

Default value: `undef`

##### `throttle`

Data type: `Optional[Variant[Integer,Float,Pattern[/^\d+(.\d+|)(k|M|G)*$/]]]`

throttle setting in the main section of yum.conf.
Rate in bytes/sec, allows a suffix of k, M, or G to be appended.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `metadata_expire`

Data type: `Optional[Variant[Integer,Pattern[/^(\d+(m|h|d)*|never|)$/]]]`

metadata_expire setting in the main section of yum.conf.
Time in seconds, allows a suffix of m, h, or d to specify minutes, hours, or days.
Alternatively you can also specify the word never instead.
When undef, it will not be present in yum.conf.

Default value: '6h'

##### `history_list_view`

Data type: `Optional[Enum['cmds','commands','default','single-user-commands','users']]`

history_list_view setting in the main section of yum.conf.
Valid values are: 'cmds', 'commands', 'default', 'single-user-commands', or 'users'.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `mdpolicy`

Data type: `Optional[Enum['group:all','group:main','group:primary','group:small','instant']]`

mdpolicy setting in the main section of yum.conf.
Valid values are: 'group:all', 'group:main', 'group:primary', 'group:small', or 'instant'.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `rpmverbosity`

Data type: `Optional[Enum['critical','debug','emergency','error','info','warn']]`

rpmverbosity setting in the main section of yum.conf.
Valid values are: 'critical', 'debug', 'emergency', 'error', 'info', or 'warn'.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `http_caching`

Data type: `Optional[Enum['all','none','packages']]`

http_caching setting in the main section of yum.conf.
Valid values are: 'all', 'none', or 'packages'.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `multilib_policy`

Data type: `Optional[Enum['all','best']]`

multilib_policy setting in the main section of yum.conf.
Valid values are: 'all' or 'best'.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `pkgpolicy`

Data type: `Optional[Enum['last', 'newest']]`

pkgpolicy setting in the main section of yum.conf.
Valid values are: 'last' or 'newest'.
When undef, it will not be present in yum.conf.

Default value: `undef`

### yum::server

Manage a yum repository service

#### Parameters

The following parameters are available in the `yum::server` class.

##### `contact_email`

Data type: `String`

Set email address for server administration contact.
Will be used for ServerAdmin in Apache vhost configuration.

Default value: 'root@localhost'

##### `docroot`

Data type: `Stdlib::Absolutepath`

Set absolute path to document root. Will be used for DocumentRoot
Apache vhost configuration.

Default value: '/opt/repos'

##### `gpg_keys_path`

Data type: `String`

Set relative path to GPG keys directory which will be in $docroot
directory. $docroot/$gpg_keys_path will be created and used.

Default value: 'keys'

##### `gpg_user_name`

Data type: `String`

Set user who signs the packages. Will be used as %_gpg_name in
/root/.rpmmacros.

Default value: 'Root'

##### `servername`

Data type: `String`

Set servername for yum repository. Will be used for ServerName in
Apache vhost configuration.

Default value: 'yum'

##### `serveraliases`

Data type: `Array[String, 1]`

Set serveraliases for yum repository. Will be used for ServerAlias Apache
vhost configuration.

Default value: [ $::fqdn, $::hostname ]

##### `http_listen_ip`

Data type: `Stdlib::IP::Address::Nosubnet`

Set listen IP for yum repository server. Will be used for VirtualHost
in Apache vhost configuration.

Default value: $::ipaddress

### yum::updatesd

Manage yum-updatesd which is available on EL5, though not EL6
This is defaulted to being disabled.

#### Parameters

The following parameters are available in the `yum::updatesd` class.

##### `updatesd_package`

Data type: `String`

Specify name of yum updatesd package.

Default value: 'yum-updatesd'

##### `updatesd_package_ensure`

Data type: `String`

Set ensure attribute for package resource. Valid values are: 'present',
'absent', 'latest', and 'purged'.

Default value: 'absent'

##### `updatesd_service`

Data type: `String`

Specify name of yum updatesd service.

Default value: 'yum-updatesd'

##### `updatesd_service_ensure`

Data type: `Stdlib::Ensure::Service`

Set ensure attribute for service resource. Valid values are: 'running'
and 'stopped'.

Default value: 'stopped'

##### `updatesd_service_enable`

Data type: `Variant[String,Boolean]`

Set enable attribute for service resource. Valid values are: 'true', 'false',
'manual', and 'mark'.

Default value: `false`

## Defined types

### yum::repo

in favor of the yumrepo type, which cannot manage files in that directory.

#### Examples

##### Using the define.

```puppet
yum::repo { 'redhat-base':
  gpgcheck => true,
}
```

#### Parameters

The following parameters are available in the `yum::repo` defined type.

##### `ensure`

Data type: `Enum['absent', 'present']`

Set to "present" or "absent". When absent, removes the repository
configuration file from the node modeled on the behavior of the
File type's ensure parameter.

Default value: 'present'

##### `repo_file_mode`

Data type: `Stdlib::Filemode`

Set the file mode of the repository configuration file.

Default value: '0400'

##### `yum_repos_d_path`

Data type: `Stdlib::Absolutepath`

Specify the path of the directory for yum repository files.

Default value: '/etc/yum.repos.d'

##### `enabled`

Data type: `Optional[Boolean]`

enabled setting in the repository file.
True enables, false disables this feature. When undef, it will not be present.

Default value: `true`

##### `enablegroups`

Data type: `Optional[Boolean]`

enablegroups setting in the repository file.
True enables, false disables this feature. When undef, it will not be present.

Default value: `undef`

##### `gpgcheck`

Data type: `Optional[Boolean]`

gpgcheck setting in the repository file.
True enables, false disables this feature. When undef, it will not be present.

Default value: `false`

##### `keepalive`

Data type: `Optional[Boolean]`

keepalive setting in the repository file.
True enables, false disables this feature. When undef, it will not be present.

Default value: `undef`

##### `repo_gpgcheck`

Data type: `Optional[Boolean]`

repo_gpgcheck setting in the repository file.
True enables, false disables this feature. When undef, it will not be present.

Default value: `undef`

##### `skip_if_unavailable`

Data type: `Optional[Boolean]`

skip_if_unavailable setting in the repository file.
True enables, false disables this feature. When undef, it will not be present.

Default value: `undef`

##### `ssl_check_cert_permissions`

Data type: `Optional[Boolean]`

ssl_check_cert_permissions setting in the repository file.
True enables, false disables this feature. When undef, it will not be present.

Default value: `undef`

##### `sslverify`

Data type: `Optional[Boolean]`

sslverify setting in the repository file.
True enables, false disables this feature. When undef, it will not be present.

Default value: `undef`

##### `bandwidth`

Data type: `Optional[Integer]`

bandwidth setting in the repository file.
Takes any integer. When undef, it will not be present.

Default value: `undef`

##### `cost`

Data type: `Optional[Integer]`

cost setting in the repository file.
Takes any integer. When undef, it will not be present.

Default value: `undef`

##### `mirrorlist_expire`

Data type: `Optional[Integer]`

mirrorlist_expire setting in the repository file.
Takes any integer. When undef, it will not be present.

Default value: `undef`

##### `retries`

Data type: `Optional[Integer]`

retries setting in the repository file.
Takes any integer. When undef, it will not be present.

Default value: `undef`

##### `timeout`

Data type: `Optional[Integer]`

timeout settingg in the repository file.
Takes any integer. When undef, it will not be present.

Default value: `undef`

##### `description`

Data type: `Optional[String]`

name setting in the repository file.
Defaults to the name of the defined type. When undef, it will not be present.

Default value: $name

##### `password`

Data type: `Optional[String]`

password setting in the repository file. When undef, it will not be present.

Default value: `undef`

##### `proxy_password`

Data type: `Optional[String]`

proxy_password setting in the repository file. When undef, it will not be present.

Default value: `undef`

##### `proxy_username`

Data type: `Optional[String]`

proxy_username setting in the repository file. When undef, it will not be present.

Default value: `undef`

##### `repositoryid`

Data type: `Optional[String]`

repositoryid setting in the repository file. When undef, it will not be present.

Default value: `undef`

##### `username`

Data type: `Optional[String]`

username setting in the repository file. When undef, it will not be present.

Default value: `undef`

##### `baseurl`

Data type: `Array[Variant[Stdlib::Httpurl,Pattern[/^(file|ftp):\/\//]]]`

baseurl setting in the repository file. Accepts HTTP/HTTPS/FTP/FILE URLs.
When undef, it will not be present.

Default value: []

##### `gpgcakey`

Data type: `Optional[Stdlib::Httpurl]`

gpgcakey setting in the repository file. Accepts HTTP/HTTPS URLs.
When undef, it will not be present.

Default value: `undef`

##### `gpgkey`

Data type: `Array[Variant[Stdlib::Httpurl,Pattern[/^(file|ftp):\/\//]]]`

gpgkey setting in the repository file.  Accepts HTTP/HTTPS/FTP/FILE URLs.
When undef, it will not be present.

Default value: []

##### `metalink`

Data type: `Optional[Stdlib::Httpurl]`

metalink setting in the repository file. Accepts HTTP/HTTPS URLs.
When undef, it will not be present.

Default value: `undef`

##### `mirrorlist`

Data type: `Optional[Stdlib::Httpurl]`

mirrorlist setting in the repository file. Accepts HTTP/HTTPS URLs.
When undef, it will not be present.

Default value: `undef`

##### `proxy`

Data type: `Optional[Variant[Stdlib::Httpurl,Enum['_none_']]]`

proxy setting in the repository file. Accepts HTTP/HTTPS URLs and '_none_'.
When undef, it will not be present.

Default value: `undef`

##### `failovermethod`

Data type: `Optional[Enum['priority','roundrobin']]`

failovermethod setting in the repository file. Valid values are: 'priority' or 'roundrobin'.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `http_caching`

Data type: `Optional[Enum['all','none','packages']]`

http_caching setting in the repository file. Valid values are: 'all', 'none', or 'packages'.
When undef, it will not be present in yum.conf.

Default value: `undef`

##### `throttle`

Data type: `Optional[Variant[Integer,Float,Pattern[/^\d+(.\d+|)(k|M|G)*$/]]]`

throttle setting in the repository file.
Rate in bytes/sec, allows a suffix of k, M, or G to be appended.
When undef, it will not be present.

Default value: `undef`

##### `metadata_expire`

Data type: `Optional[Variant[Integer,Pattern[/^(\d+(m|h|d)*|never|)$/]]]`

metadata_expire setting in the repository file.
Time in seconds, allows a suffix of m, h, or d to specify minutes, hours, or days.
Alternatively you can also specify the word never instead.
When undef, it will not be present.

Default value: `undef`

##### `sslcacert`

Data type: `Optional[Stdlib::Absolutepath]`

sslcacert setting in the repository file.
When undef, it will not be present.

Default value: `undef`

##### `sslclientcert`

Data type: `Optional[Stdlib::Absolutepath]`

sslclientcert setting in the repository file.
When undef, it will not be present.

Default value: `undef`

##### `sslclientkey`

Data type: `Optional[Stdlib::Absolutepath]`

sslclientkey setting in the repository file.
When undef, it will not be present.

Default value: `undef`

##### `exclude`

Data type: `Array`

exclude setting in the repository file.
When empty, it will not be present.

Default value: []

##### `includepkgs`

Data type: `Array`

includepkgs setting in the repository file.
When empty, it will not be present.

Default value: []

### yum::rpm_gpg_key

Downloads a public gpg key for a yum repo and installs the key
Uses wget and rpimport commands

#### Parameters

The following parameters are available in the `yum::rpm_gpg_key` defined type.

##### `gpgkey_url`

Data type: `Stdlib::Httpurl`

Specify the source URL for the GPG key to download from.

##### `gpgkey`

Data type: `Stdlib::Absolutepath`

Specify the fully qualified destination file name for the GPG key to save to.

##### `wget_path`

Data type: `String`

Specify the path parameter to be used for the wget command.

Default value: '/bin:/usr/bin:/sbin:/usr/sbin'

##### `rpm_path`

Data type: `String`

Specify the path parameter to be used for the rpm command.

Default value: '/bin:/usr/bin:/sbin:/usr/sbin'

